==> yams-1.2.3.tar.gz: yams-1.2.3/src/hwcons.h <==
/* A Bison parser, made from /u/5/lsalmela/projekti/buenos/temp/buenos/yams/src/hwcons.y, by GNU bison 1.50.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

#ifndef BISON_Y_TAB_H
# define BISON_Y_TAB_H

/* Tokens.  */
#ifndef YYTOKENTYPE
# if defined (__STDC__) || defined (__cplusplus)
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     CMDTERM = 258,
     START = 259,
     STEP = 260,
     BREAK = 261,
     QUIT = 262,
     INTERRUPT = 263,
     REGDUMP = 264,
     REGWRITE = 265,
     MEMWRITE = 266,
     MEMREAD = 267,
     HELP = 268,
     UNBREAK = 269,
     DUMP = 270,
     POKE = 271,
     TLBDUMP = 272,
     BOOT = 273,
     CPUREGISTER = 274,
     CP0REGISTER = 275,
     INTEGER32 = 276,
     COLON = 277,
     STRING = 278,
     ERROR = 279
   };
# endif
  /* POSIX requires `int' for tokens in interfaces.  */
# define YYTOKENTYPE int
#endif /* !YYTOKENTYPE */
#define CMDTERM 258
#define START 259
#define STEP 260
#define BREAK 261
#define QUIT 262
#define INTERRUPT 263
#define REGDUMP 264
#define REGWRITE 265
#define MEMWRITE 266
#define MEMREAD 267
#define HELP 268
#define UNBREAK 269
#define DUMP 270
#define POKE 271
#define TLBDUMP 272
#define BOOT 273
#define CPUREGISTER 274
#define CP0REGISTER 275
#define INTEGER32 276
#define COLON 277
#define STRING 278
#define ERROR 279




#ifndef YYSTYPE
#line 113 "hwcons.y"
typedef union {
	uint32_t intvalue;
	char *stringvalue;
} yystype;
/* Line 1304 of /u/projects/buenos/util/src/bison-1.50-install/share/bison/yacc.c.  */
#line 96 "hwcons.h"
# define YYSTYPE yystype
#endif

extern YYSTYPE yylval;


#endif /* not BISON_Y_TAB_H */

==> yams-1.3.0.tar.gz: yams-1.3.0/src/hwcons.h <==
/* A Bison parser, made from /u/5/lsalmela/releases/buenos/yams/src/hwcons.y, by GNU bison 1.75.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

#ifndef BISON_Y_TAB_H
# define BISON_Y_TAB_H

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     CMDTERM = 258,
     START = 259,
     STEP = 260,
     BREAK = 261,
     QUIT = 262,
     INTERRUPT = 263,
     REGDUMP = 264,
     REGWRITE = 265,
     MEMWRITE = 266,
     MEMREAD = 267,
     HELP = 268,
     UNBREAK = 269,
     DUMP = 270,
     POKE = 271,
     TLBDUMP = 272,
     BOOT = 273,
     CPUREGISTER = 274,
     CP0REGISTER = 275,
     INTEGER32 = 276,
     COLON = 277,
     STRING = 278,
     ERROR = 279
   };
#endif
#define CMDTERM 258
#define START 259
#define STEP 260
#define BREAK 261
#define QUIT 262
#define INTERRUPT 263
#define REGDUMP 264
#define REGWRITE 265
#define MEMWRITE 266
#define MEMREAD 267
#define HELP 268
#define UNBREAK 269
#define DUMP 270
#define POKE 271
#define TLBDUMP 272
#define BOOT 273
#define CPUREGISTER 274
#define CP0REGISTER 275
#define INTEGER32 276
#define COLON 277
#define STRING 278
#define ERROR 279




#ifndef YYSTYPE
#line 113 "hwcons.y"
typedef union {
	uint32_t intvalue;
	char *stringvalue;
} yystype;
/* Line 1281 of /usr/local/share/bison/yacc.c.  */
#line 93 "hwcons.h"
# define YYSTYPE yystype
#endif

extern YYSTYPE yylval;


#endif /* not BISON_Y_TAB_H */
